==> opensign-1.0.1.tar.gz: opensign/src/Form/OpenSignConfigForm.php <==
<?php

namespace Drupal\opensign\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures opensign’s settings.
 */
class OpenSignConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'opensign_server_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'opensign.server_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('opensign.server_settings');
    $form['opensign_app_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('App ID'),
      '#default_value' => $config->get('opensign_app_id'),
    ];
    $form['opensign_app_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('App name'),
      '#default_value' => $config->get('opensign_app_name'),
    ];
    $form['opensign_master_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Master Key'),
      '#default_value' => $config->get('opensign_master_key'),
    ];
    $form['opensign_rest_api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('App Rest API key'),
      '#default_value' => $config->get('opensign_rest_api_key'),
    ];
    $form['opensign_server_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Server URL'),
      '#default_value' => $config->get('opensign_server_url'),
    ];
    $form['opensign_server_mount'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Server Mount'),
      '#default_value' => $config->get('opensign_server_mount'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('opensign.server_settings')
      ->set('opensign_app_id', $form_state->getValue('opensign_app_id'))
      ->set('opensign_app_name', $form_state->getValue('opensign_app_name'))
      ->set('opensign_rest_api_key', $form_state->getValue('opensign_rest_api_key'))
      ->set('opensign_master_key', $form_state->getValue('opensign_master_key'))
      ->set('opensign_server_url', $form_state->getValue('opensign_server_url'))
      ->set('opensign_server_mount', $form_state->getValue('opensign_server_mount'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}

==> opensign-1.0.2.tar.gz: opensign/src/Form/OpenSignConfigForm.php <==
<?php

namespace Drupal\opensign\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures opensign’s settings.
 */
class OpenSignConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'opensign_server_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'opensign.server_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('opensign.server_settings');
    $form['opensign_app_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('App ID'),
      '#default_value' => $config->get('opensign_app_id'),
    ];

    $form['opensign_rest_api_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('App Rest API key'),
      '#default_value' => $config->get('opensign_rest_api_token'),
    ];
    $form['opensign_server_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Server URL'),
      '#default_value' => $config->get('opensign_server_url'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('opensign.server_settings')
      ->set('opensign_app_id', $form_state->getValue('opensign_app_id'))
      ->set('opensign_rest_api_token', $form_state->getValue('opensign_rest_api_token'))
      ->set('opensign_server_url', $form_state->getValue('opensign_server_url'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
